==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/request/EmbeddedSIMActivationCodePoolRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.List;
import java.util.Map;

import odata.msgraph.client.beta.entity.EmbeddedSIMActivationCodePool;
import odata.msgraph.client.beta.entity.EmbeddedSIMActivationCodePoolAssignment;
import odata.msgraph.client.beta.entity.collection.request.EmbeddedSIMActivationCodePoolAssignmentCollectionRequest;
import odata.msgraph.client.beta.entity.collection.request.EmbeddedSIMDeviceStateCollectionRequest;
import odata.msgraph.client.beta.schema.SchemaInfo;

@JsonIgnoreType
public class EmbeddedSIMActivationCodePoolRequest extends EntityRequest<EmbeddedSIMActivationCodePool> {

    public EmbeddedSIMActivationCodePoolRequest(ContextPath contextPath) {
        super(EmbeddedSIMActivationCodePool.class, contextPath, SchemaInfo.INSTANCE);
    }

    public EmbeddedSIMActivationCodePoolAssignmentCollectionRequest assignments() {
        return new EmbeddedSIMActivationCodePoolAssignmentCollectionRequest(
                        contextPath.addSegment("assignments"));
    }

    public EmbeddedSIMActivationCodePoolAssignmentRequest assignments(String id) {
        return new EmbeddedSIMActivationCodePoolAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id.toString())));
    }

    public EmbeddedSIMDeviceStateCollectionRequest deviceStates() {
        return new EmbeddedSIMDeviceStateCollectionRequest(
                        contextPath.addSegment("deviceStates"));
    }

    public EmbeddedSIMDeviceStateRequest deviceStates(String id) {
        return new EmbeddedSIMDeviceStateRequest(contextPath.addSegment("deviceStates").addKeys(new NameValue(id.toString())));
    }

    @Action(name = "assign")
    @JsonIgnore
    public CollectionPageNonEntityRequest<EmbeddedSIMActivationCodePoolAssignment> assign(List<EmbeddedSIMActivationCodePoolAssignment> assignments) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("assignments", "Collection(microsoft.graph.embeddedSIMActivationCodePoolAssignment)", assignments)
            .build();
        return CollectionPageNonEntityRequest.forAction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.assign"), EmbeddedSIMActivationCodePoolAssignment.class, _parameters, odata.msgraph.client.beta.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/request/EmbeddedSIMActivationCodePoolRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.List;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.entity.EmbeddedSIMActivationCodePool;
import odata.msgraph.client.beta.entity.EmbeddedSIMActivationCodePoolAssignment;
import odata.msgraph.client.beta.entity.collection.request.EmbeddedSIMActivationCodePoolAssignmentCollectionRequest;
import odata.msgraph.client.beta.entity.collection.request.EmbeddedSIMDeviceStateCollectionRequest;

@JsonIgnoreType
public class EmbeddedSIMActivationCodePoolRequest extends EntityRequest<EmbeddedSIMActivationCodePool> {

    public EmbeddedSIMActivationCodePoolRequest(ContextPath contextPath, Optional<Object> value) {
        super(EmbeddedSIMActivationCodePool.class, contextPath, value, false);
    }

    public EmbeddedSIMActivationCodePoolAssignmentRequest assignments(String id) {
        return new EmbeddedSIMActivationCodePoolAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id, String.class)), Optional.empty());
    }

    public EmbeddedSIMActivationCodePoolAssignmentCollectionRequest assignments() {
        return new EmbeddedSIMActivationCodePoolAssignmentCollectionRequest(
                        contextPath.addSegment("assignments"), Optional.empty());
    }

    public EmbeddedSIMDeviceStateRequest deviceStates(String id) {
        return new EmbeddedSIMDeviceStateRequest(contextPath.addSegment("deviceStates").addKeys(new NameValue(id, String.class)), Optional.empty());
    }

    public EmbeddedSIMDeviceStateCollectionRequest deviceStates() {
        return new EmbeddedSIMDeviceStateCollectionRequest(
                        contextPath.addSegment("deviceStates"), Optional.empty());
    }

    @Action(name = "assign")
    @JsonIgnore
    public CollectionPageNonEntityRequest<EmbeddedSIMActivationCodePoolAssignment> assign(List<EmbeddedSIMActivationCodePoolAssignment> assignments) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("assignments", "Collection(microsoft.graph.embeddedSIMActivationCodePoolAssignment)", assignments)
            .build();
        return CollectionPageNonEntityRequest.forAction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.assign"), EmbeddedSIMActivationCodePoolAssignment.class, _parameters);
    }

}
